@@ -22,6 +22,7 @@
 ### THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 import os
+from gettext import gettext as _
 import re
 import time
 import misc
@@ -36,6 +37,7 @@ class Vc(_vc.Vc):
     def __init__(self, location):
         if not os.path.exists("%s/CVS"% location):
             raise ValueError
+        self.root = location
 
     def commit_command(self, message):
         return [self.CMD,"commit","-m",message]
